@@ -1,16 +1,25 @@
 import json
 import logging
 from decimal import Decimal
+from functools import cached_property
 from functools import lru_cache
-from os.path import exists, expanduser
-from typing import Any, Callable, Dict, List, Optional, Type, Union
+from os.path import exists
+from os.path import expanduser
+from typing import Any
+from typing import Callable
+from typing import Dict
+from typing import List
+from typing import Optional
+from typing import Type
+from typing import Union
+from typing import cast
 from urllib.parse import urlparse
 
 import requests
-from cached_property import cached_property  # type: ignore
 from deprecation import deprecated  # type: ignore
 
-from pytezos.context.mixin import ContextMixin, ExecutionContext
+from pytezos.context.mixin import ContextMixin
+from pytezos.context.mixin import ExecutionContext
 from pytezos.contract.data import ContractData
 from pytezos.contract.entrypoint import ContractEntrypoint
 from pytezos.contract.metadata import ContractMetadata
@@ -25,7 +34,8 @@ from pytezos.michelson.micheline import MichelsonRuntimeError
 from pytezos.michelson.parse import michelson_to_micheline
 from pytezos.michelson.program import MichelsonProgram
 from pytezos.michelson.sections import ViewSection
-from pytezos.michelson.types import BigMapType, BytesType
+from pytezos.michelson.types import BigMapType
+from pytezos.michelson.types import BytesType
 from pytezos.michelson.types.base import generate_pydoc
 from pytezos.operation.group import OperationGroup
 from pytezos.rpc import ShellQuery
@@ -125,7 +135,10 @@ class ContractInterface(ContextMixin):
         return ContractInterface.from_micheline(michelson_to_micheline(source), context)
 
     @staticmethod
-    def from_micheline(expression: List[Dict[str, Any]], context: Optional[ExecutionContext] = None) -> 'ContractInterface':
+    def from_micheline(
+        expression: List[Dict[str, Any]],
+        context: Optional[ExecutionContext] = None,
+    ) -> 'ContractInterface':
         """Create contract from micheline expression.
 
         :param expression: [{'prim': 'parameter'}, {'prim': 'storage'}, {'prim': 'code'}]
@@ -137,11 +150,11 @@ class ContractInterface(ContextMixin):
         else:
             code_expr = expression
         program = MichelsonProgram.match(code_expr)
-        cls = type(ContractInterface.__name__, (ContractInterface,), dict(program=program))
+        cls = type(ContractInterface.__name__, (ContractInterface,), {'program': program})
         context = ExecutionContext(
             shell=context.shell if context else None,
             key=context.key if context else None,
-            script=dict(code=code_expr),
+            script={'code': code_expr},
             global_constants=context.global_constants if context else None,
         )
         return cls(context)
@@ -154,7 +167,7 @@ class ContractInterface(ContextMixin):
         :return: ContractInterface
         """
         program = MichelsonProgram.load(context, with_code=True)
-        cls = type(ContractInterface.__name__, (ContractInterface,), dict(program=program))
+        cls = type(ContractInterface.__name__, (ContractInterface,), {'program': program})
         return cls(context)
 
     @classmethod
@@ -342,7 +355,7 @@ class ContractInterface(ContextMixin):
         """
         return ContractTokenMetadataProxy(self._get_token_metadata)  # type: ignore
 
-    @lru_cache(maxsize=None)
+    @lru_cache(maxsize=1000)  # noqa: B019
     def _get_token_metadata(self, token_id: int) -> Optional[ContractTokenMetadata]:
         token_metadata = self._get_token_metadata_from_view(token_id)
         if token_metadata is None:
@@ -390,7 +403,7 @@ class ContractInterface(ContextMixin):
     def _get_token_metadata_from_view(self, token_id: int) -> Optional[ContractTokenMetadata]:
         self._logger.info('Trying to fetch token %s metadata from off-chain view', token_id)
         try:
-            token_metadata_json = self.metadata.tokenMetadata(token_id).storage_view()[1]
+            token_metadata_json = cast(ContractMetadata, self.metadata).tokenMetadata(token_id).storage_view()[1]
             return ContractTokenMetadata.from_json(token_metadata_json)
         except KeyError:
             self._logger.info('There\'s no off-chain view named `token_metadata`')
