@@ -1,19 +1,24 @@
 from pprint import pformat
-from typing import Any, Dict, List, Optional
+from typing import Any
+from typing import Dict
+from typing import List
+from typing import Optional
 
 from pytezos.context.impl import ExecutionContext
 from pytezos.context.mixin import ContextMixin
-from pytezos.contract.call import ContractCallResult, skip_nones
+from pytezos.contract.call import ContractCallResult
+from pytezos.contract.call import skip_nones
 from pytezos.jupyter import get_class_docstring
 from pytezos.logging import logger
 from pytezos.michelson.micheline import MichelsonRuntimeError
 from pytezos.michelson.repl import Interpreter
-from pytezos.michelson.types.base import MichelsonType, generate_pydoc
+from pytezos.michelson.types.base import MichelsonType
+from pytezos.michelson.types.base import generate_pydoc
 
 
 def format_view_script(param_ty_expr, storage_ty_expr, return_ty_expr, code_expr):
-    return dict(
-        code=[
+    return {
+        'code': [
             {
                 'prim': 'parameter',
                 'args': [
@@ -53,7 +58,7 @@ def format_view_script(param_ty_expr, storage_ty_expr, return_ty_expr, code_expr
                 ],
             },
         ]
-    )
+    }
 
 
 def format_view_params(param_expr, storage_expr):
@@ -133,7 +138,13 @@ class ContractViewCall(ContextMixin):
     """Proxy class encapsulating a contract call: contract type scheme, contract address, parameters, and amount"""
 
     def __init__(
-        self, context: ExecutionContext, param_expr: dict, param_ty_expr: dict, return_ty_expr: dict, code_expr: list, name: str
+        self,
+        context: ExecutionContext,
+        param_expr: dict,
+        param_ty_expr: dict,
+        return_ty_expr: dict,
+        code_expr: list,
+        name: str,
     ) -> None:
         super().__init__(context=context)
         self.name = name
@@ -225,7 +236,10 @@ class ContractViewCall(ContextMixin):
         :param storage: override current contract storage (as Python object)
         :returns: Decoded return value
         """
-        parameters = format_view_params(param_expr=self.param_expr, storage_expr=self._get_storage(storage))
+        parameters = format_view_params(
+            param_expr=self.param_expr,
+            storage_expr=self._get_storage(storage),
+        )
         script = format_view_script(
             param_ty_expr=self.param_ty_expr,
             storage_ty_expr=self.context.storage_expr,
@@ -257,7 +271,10 @@ class ContractViewCall(ContextMixin):
             storage=self._get_storage(storage),
             context=self._spawn_context(
                 balance=balance,
-                script={**self.context.script, 'storage': self._encode_storage(storage)},  # type: ignore
+                script={
+                    **self.context.script,  # type: ignore
+                    'storage': self._encode_storage(storage),
+                },
                 view_results=view_results,
             ),
         )
