@@ -1,4 +1,11 @@
-from typing import Any, Dict, List, Optional, Tuple, Type, Union, cast
+from typing import Any
+from typing import Dict
+from typing import List
+from typing import Optional
+from typing import Tuple
+from typing import Type
+from typing import Union
+from typing import cast
 
 from pytezos.context.abstract import AbstractContext
 from pytezos.michelson.micheline import Micheline
@@ -6,7 +13,6 @@ from pytezos.michelson.stack import MichelsonStack
 
 
 class Wildcard:
-
     @staticmethod
     def n(count: int) -> List['Wildcard']:
         return [Wildcard() for _ in range(count)]
@@ -22,8 +28,10 @@ def format_stdout(prim: str, inputs: list, outputs: list, arg=None):
     return f'{prim}{arg} / {pop} => {push}'
 
 
-def dispatch_types(*args: Type[Micheline],
-                   mapping: Dict[Tuple[Type[Micheline], ...], Tuple[Any, ...]]):
+def dispatch_types(
+    *args: Type[Micheline],
+    mapping: Dict[Tuple[Type[Micheline], ...], Tuple[Any, ...]],
+):
     key = tuple(arg.prim for arg in args)
     mapping = {tuple(arg.prim for arg in k): v for k, v in mapping.items()}  # type: ignore
     assert key in mapping, f'unexpected types `{" * ".join(key)}`'  # type: ignore
@@ -43,19 +51,27 @@ class MichelsonInstruction(Micheline):
         return cast(Type['MichelsonInstruction'], Micheline.match(expr))
 
     @classmethod
-    def create_type(cls,
-                    args: List[Type['Micheline']],
-                    annots: Optional[list] = None,
-                    **kwargs) -> Type['MichelsonInstruction']:
+    def create_type(
+        cls,
+        args: List[Type['Micheline']],
+        annots: Optional[list] = None,
+        **kwargs,
+    ) -> Type['MichelsonInstruction']:
         if annots:
             field_names = [a[1:] for a in annots if a.startswith('%')]
             var_names = [a[1:] for a in annots if a.startswith('@')]
         else:
             field_names, var_names = [], []
-        res = type(cls.__name__, (cls,), dict(args=args,
-                                              field_names=field_names,
-                                              var_names=var_names,
-                                              **kwargs))
+        res = type(
+            cls.__name__,
+            (cls,),
+            {
+                'args': args,
+                'field_names': field_names,
+                'var_names': var_names,
+                **kwargs,
+            },
+        )
         return cast(Type['MichelsonInstruction'], res)
 
     @classmethod
@@ -66,7 +82,7 @@ class MichelsonInstruction(Micheline):
         if cls.field_names is not None:
             annots.extend([f'%{x}' for x in cls.field_names])
         args = [arg.as_micheline_expr() for arg in cls.args]
-        expr = dict(prim=cls.prim, annots=annots, args=args)
+        expr = {'prim': cls.prim, 'annots': annots, 'args': args}
         return {k: v for k, v in expr.items() if v}
 
     @classmethod
