@@ -1,9 +1,13 @@
-from typing import Callable, List, cast
+from typing import Callable
+from typing import List
+from typing import cast
 
 from pytezos.context.abstract import AbstractContext
-from pytezos.michelson.instructions.base import MichelsonInstruction, format_stdout
+from pytezos.michelson.instructions.base import MichelsonInstruction
+from pytezos.michelson.instructions.base import format_stdout
 from pytezos.michelson.stack import MichelsonStack
-from pytezos.michelson.types import BoolType, IntType
+from pytezos.michelson.types import BoolType
+from pytezos.michelson.types import IntType
 
 
 def compare(a, b) -> int:
@@ -16,7 +20,6 @@ def compare(a, b) -> int:
 
 
 class CompareInstruction(MichelsonInstruction, prim='COMPARE'):
-
     @classmethod
     def execute(cls, stack: MichelsonStack, stdout: List[str], context: AbstractContext):
         a, b = stack.pop2()
@@ -36,7 +39,6 @@ def execute_zero_compare(prim: str, stack: MichelsonStack, stdout: List[str], co
 
 
 class EqInstruction(MichelsonInstruction, prim='EQ'):
-
     @classmethod
     def execute(cls, stack: MichelsonStack, stdout: List[str], context: AbstractContext):
         execute_zero_compare(cls.prim, stack, stdout, lambda x: x == 0)  # type: ignore
@@ -44,7 +46,6 @@ class EqInstruction(MichelsonInstruction, prim='EQ'):
 
 
 class GeInstruction(MichelsonInstruction, prim='GE'):
-
     @classmethod
     def execute(cls, stack: MichelsonStack, stdout: List[str], context: AbstractContext):
         execute_zero_compare(cls.prim, stack, stdout, lambda x: x >= 0)  # type: ignore
@@ -52,7 +53,6 @@ class GeInstruction(MichelsonInstruction, prim='GE'):
 
 
 class GtInstruction(MichelsonInstruction, prim='GT'):
-
     @classmethod
     def execute(cls, stack: MichelsonStack, stdout: List[str], context: AbstractContext):
         execute_zero_compare(cls.prim, stack, stdout, lambda x: x > 0)  # type: ignore
@@ -60,7 +60,6 @@ class GtInstruction(MichelsonInstruction, prim='GT'):
 
 
 class LeInstruction(MichelsonInstruction, prim='LE'):
-
     @classmethod
     def execute(cls, stack: MichelsonStack, stdout: List[str], context: AbstractContext):
         execute_zero_compare(cls.prim, stack, stdout, lambda x: x <= 0)  # type: ignore
@@ -68,7 +67,6 @@ class LeInstruction(MichelsonInstruction, prim='LE'):
 
 
 class LtInstruction(MichelsonInstruction, prim='LT'):
-
     @classmethod
     def execute(cls, stack: MichelsonStack, stdout: List[str], context: AbstractContext):
         execute_zero_compare(cls.prim, stack, stdout, lambda x: x < 0)  # type: ignore
@@ -76,7 +74,6 @@ class LtInstruction(MichelsonInstruction, prim='LT'):
 
 
 class NeqInstruction(MichelsonInstruction, prim='NEQ'):
-
     @classmethod
     def execute(cls, stack: MichelsonStack, stdout: List[str], context: AbstractContext):
         execute_zero_compare(cls.prim, stack, stdout, lambda x: x != 0)  # type: ignore
