@@ -1,4 +1,5 @@
-from typing import List, Type
+from typing import List
+from typing import Type
 
 from pytezos.context.abstract import AbstractContext
 from pytezos.michelson.micheline import Micheline
@@ -6,7 +7,6 @@ from pytezos.michelson.micheline import Micheline
 
 # FIXME: CodeSection copypaste
 class InputSection(Micheline, prim='input', args_len=1):
-
     @staticmethod
     def match(input_expr) -> Type['InputSection']:
         cls = Micheline.match(input_expr)
@@ -22,7 +22,6 @@ class InputSection(Micheline, prim='input', args_len=1):
 
 # FIXME: CodeSection copypaste
 class OutputSection(Micheline, prim='output', args_len=1):
-
     @staticmethod
     def match(output_expr) -> Type['OutputSection']:
         cls = Micheline.match(output_expr)
@@ -38,7 +37,6 @@ class OutputSection(Micheline, prim='output', args_len=1):
 
 # FIXME: CodeSection copypaste
 class SenderSection(Micheline, prim='sender', args_len=1):
-
     @staticmethod
     def match(output_expr) -> Type['SenderSection']:
         cls = Micheline.match(output_expr)
@@ -51,9 +49,9 @@ class SenderSection(Micheline, prim='sender', args_len=1):
         context.set_sender_expr(cls.as_micheline_expr())
         stdout.append('sender: updated')
 
+
 # FIXME: CodeSection copypaste
 class BalanceSection(Micheline, prim='balance', args_len=1):
-
     @staticmethod
     def match(output_expr) -> Type['BalanceSection']:
         cls = Micheline.match(output_expr)
@@ -66,9 +64,9 @@ class BalanceSection(Micheline, prim='balance', args_len=1):
         context.set_balance_expr(cls.as_micheline_expr())
         stdout.append('balance: updated')
 
+
 # FIXME: CodeSection copypaste
 class AmountSection(Micheline, prim='amount', args_len=1):
-
     @staticmethod
     def match(output_expr) -> Type['AmountSection']:
         cls = Micheline.match(output_expr)
@@ -84,7 +82,6 @@ class AmountSection(Micheline, prim='amount', args_len=1):
 
 # FIXME: CodeSection copypaste
 class SelfSection(Micheline, prim='self', args_len=1):
-
     @staticmethod
     def match(output_expr) -> Type['SelfSection']:
         cls = Micheline.match(output_expr)
@@ -100,7 +97,6 @@ class SelfSection(Micheline, prim='self', args_len=1):
 
 # FIXME: CodeSection copypaste
 class NowSection(Micheline, prim='now', args_len=1):
-
     @staticmethod
     def match(output_expr) -> Type['NowSection']:
         cls = Micheline.match(output_expr)
@@ -116,7 +112,6 @@ class NowSection(Micheline, prim='now', args_len=1):
 
 # FIXME: CodeSection copypaste
 class SourceSection(Micheline, prim='source', args_len=1):
-
     @staticmethod
     def match(output_expr) -> Type['SourceSection']:
         cls = Micheline.match(output_expr)
@@ -132,7 +127,6 @@ class SourceSection(Micheline, prim='source', args_len=1):
 
 # FIXME: CodeSection copypaste
 class ChainIdSection(Micheline, prim='chain_id', args_len=1):
-
     @staticmethod
     def match(output_expr) -> Type['ChainIdSection']:
         cls = Micheline.match(output_expr)
@@ -148,7 +142,6 @@ class ChainIdSection(Micheline, prim='chain_id', args_len=1):
 
 # FIXME: CodeSection copypaste
 class BigMapsSection(Micheline, prim='big_maps', args_len=1):
-
     @staticmethod
     def match(output_expr) -> Type['BigMapsSection']:
         cls = Micheline.match(output_expr)
@@ -159,4 +152,4 @@ class BigMapsSection(Micheline, prim='big_maps', args_len=1):
     @classmethod
     def execute(cls, stack, stdout: List[str], context: AbstractContext):
         context.set_big_maps_expr(cls.as_micheline_expr())
-        stdout.append('big_maps: updated')
\ No newline at end of file
+        stdout.append('big_maps: updated')
