@@ -1,11 +1,20 @@
-from typing import Dict, Generator, List, Optional, Tuple, Type, Union
+from typing import Dict
+from typing import Generator
+from typing import List
+from typing import Optional
+from typing import Tuple
+from typing import Type
+from typing import Union
 
-from pytezos.michelson.types.base import MichelsonType, Undefined
+from pytezos.michelson.types.base import MichelsonType
+from pytezos.michelson.types.base import Undefined
 
 
-def get_type_layout(flat_args: List[Tuple[str, Type[MichelsonType]]],
-                    infer_names: bool = False, entrypoints: bool = False) \
-        -> Tuple[Optional[Dict[str, str]], Optional[Dict[str, str]], Dict[int, str]]:
+def get_type_layout(
+    flat_args: List[Tuple[str, Type[MichelsonType]]],
+    infer_names: bool = False,
+    entrypoints: bool = False,
+) -> Tuple[Optional[Dict[str, str]], Optional[Dict[str, str]], Dict[int, str]]:
     reserved = set()
     path_to_key = {}
     for i, (bin_path, arg) in enumerate(flat_args):
@@ -29,7 +38,6 @@ def get_type_layout(flat_args: List[Tuple[str, Type[MichelsonType]]],
 
 
 class Nested:
-
     def __init__(self, *args):
         self.args = args
 
@@ -45,18 +53,14 @@ def wrap_or(obj, path) -> Nested:
     elif path[0] == '1':
         return Nested(Undefined, wrap_or(obj, path[1:]))
     else:
-        assert False, path
+        raise AssertionError(path)
 
 
 def wrap_pair(obj: dict, path='') -> Nested:
     if all(not x.startswith(path) for x in obj):
         raise KeyError(path)
 
-    items = [
-        obj[subpath] if subpath in obj else wrap_pair(obj, subpath)
-        for subpath
-        in [path + '0', path + '1']
-    ]
+    items = [obj[subpath] if subpath in obj else wrap_pair(obj, subpath) for subpath in [path + '0', path + '1']]
     return Nested(*items)
 
 
@@ -68,18 +72,25 @@ def wrap_parameters(expr, path):
     elif path[0] == '1':
         return {'prim': 'Right', 'args': [wrap_parameters(expr, path[1:])]}
     else:
-        assert False, path
+        raise AssertionError(path)
 
 
 class ADTMixin:
-
     @classmethod
-    def iter_type_args(cls, entrypoints: bool = False, path='') -> Generator[Tuple[str, Type[MichelsonType]], None, None]:
+    def iter_type_args(
+        cls,
+        entrypoints: bool = False,
+        path='',
+    ) -> Generator[Tuple[str, Type[MichelsonType]], None, None]:
         raise NotImplementedError
 
     @classmethod
-    def get_flat_args(cls, infer_names: bool = False, force_tuple: bool = False, entrypoints: bool = False) \
-            -> Union[Dict[str, Type[MichelsonType]], List[Type[MichelsonType]]]:
+    def get_flat_args(
+        cls,
+        infer_names: bool = False,
+        force_tuple: bool = False,
+        entrypoints: bool = False,
+    ) -> Union[Dict[str, Type[MichelsonType]], List[Type[MichelsonType]]]:
         flat_args = list(cls.iter_type_args(entrypoints=entrypoints))
         if force_tuple is False:
             path_to_key, _, _ = get_type_layout(flat_args, infer_names=infer_names, entrypoints=entrypoints)
@@ -88,16 +99,23 @@ class ADTMixin:
         return [arg for _, arg in flat_args]
 
     @classmethod
-    def get_type_layout(cls, infer_names: bool = False, entrypoints: bool = False) \
-            -> Tuple[Optional[Dict[str, str]], Optional[Dict[str, str]], Dict[int, str]]:
+    def get_type_layout(
+        cls,
+        infer_names: bool = False,
+        entrypoints: bool = False,
+    ) -> Tuple[Optional[Dict[str, str]], Optional[Dict[str, str]], Dict[int, str]]:
         flat_args = list(cls.iter_type_args(entrypoints=entrypoints))
         return get_type_layout(flat_args, infer_names=infer_names, entrypoints=entrypoints)
 
     def iter_values(self, path='') -> Generator[Tuple[str, MichelsonType], None, None]:
         raise NotImplementedError
 
-    def get_flat_values(self, infer_names: bool = False, force_tuple: bool = False, entrypoints: bool = False) \
-            -> Union[Dict[str, MichelsonType], List[MichelsonType]]:
+    def get_flat_values(
+        self,
+        infer_names: bool = False,
+        force_tuple: bool = False,
+        entrypoints: bool = False,
+    ) -> Union[Dict[str, MichelsonType], List[MichelsonType]]:
         path_to_key, _, _ = self.get_type_layout(infer_names=infer_names, entrypoints=entrypoints)
         flat_values = list(self.iter_values())
         if force_tuple is False and isinstance(path_to_key, dict):
@@ -113,5 +131,5 @@ class ADTMixin:
         elif isinstance(key, int):
             path = idx_to_path[key]
         else:
-            assert False, f'expected string or int, got {key}'
+            raise AssertionError(f'expected string or int, got {key}')
         return next(v for p, v in self.iter_values() if p == path)
