@@ -1,7 +1,11 @@
-from typing import Callable, List, Optional, Type
+from typing import Callable
+from typing import List
+from typing import Optional
+from typing import Type
 
 from pytezos.context.abstract import AbstractContext
-from pytezos.michelson.micheline import Micheline, parse_micheline_value
+from pytezos.michelson.micheline import Micheline
+from pytezos.michelson.micheline import parse_micheline_value
 from pytezos.michelson.types.base import MichelsonType
 
 
@@ -14,7 +18,6 @@ class SomeLiteral(Micheline, prim='Some', args_len=1):
 
 
 class OptionType(MichelsonType, prim='option', args_len=1):
-
     def __init__(self, item: Optional[MichelsonType]):
         super(OptionType, self).__init__()
         self.item = item
@@ -60,10 +63,13 @@ class OptionType(MichelsonType, prim='option', args_len=1):
 
     @classmethod
     def from_micheline_value(cls, val_expr):
-        item = parse_micheline_value(val_expr, {
-            ('Some', 1): lambda x: cls.args[0].from_micheline_value(x[0]),
-            ('None', 0): lambda x: None
-        })
+        item = parse_micheline_value(
+            val_expr,
+            {
+                ('Some', 1): lambda x: cls.args[0].from_micheline_value(x[0]),
+                ('None', 0): lambda x: None,
+            },
+        )
         return cls(item)
 
     @classmethod
@@ -98,9 +104,11 @@ class OptionType(MichelsonType, prim='option', args_len=1):
         if self.is_none():
             return None
         else:
-            return self.item.to_python_object(try_unpack=try_unpack,
-                                              lazy_diff=lazy_diff,
-                                              comparable=comparable)
+            return self.item.to_python_object(
+                try_unpack=try_unpack,
+                lazy_diff=lazy_diff,
+                comparable=comparable,
+            )
 
     def merge_lazy_diff(self, lazy_diff: List[dict]) -> 'MichelsonType':
         item = None if self.is_none() else self.item.merge_lazy_diff(lazy_diff)  # type: ignore
