@@ -1,5 +1,6 @@
 from pytezos.rpc.helpers import *
-from pytezos.rpc.node import RpcMultiNode, RpcNode
+from pytezos.rpc.node import RpcMultiNode
+from pytezos.rpc.node import RpcNode
 from pytezos.rpc.protocol import *
 from pytezos.rpc.search import *
 from pytezos.rpc.shell import *
